.. -*- mode: rst -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:

.. _chap_modref:

***********************
Python module reference
***********************

This module reference extends the manual with a comprehensive overview of the
available functionality built into niceman.  Each module in the package is
documented by a general summary of its purpose and the list of classes and
functions it provides.


High-level user interface
=========================

.. currentmodule:: niceman
.. autosummary::
   :toctree: generated

   api

Plumbing
========

.. currentmodule:: niceman
.. autosummary::
   :toctree: generated

   cmd
   consts
   log
   utils
   version
   support.configparserinc

Configuration management
========================

.. currentmodule:: niceman
.. autosummary::
   :toctree: generated

   config

Test infrastructure
===================

.. currentmodule:: niceman
.. autosummary::
   :toctree: generated

   tests.utils

Command line interface infrastructure
=====================================

.. currentmodule:: niceman
.. autosummary::
   :toctree: generated

   cmdline.main
   cmdline.helpers
   cmdline.common_args
